@@ -3,7 +3,7 @@ import typer
 from . import _drivers
 
 
-def _download(
+def _main(
     *,
     driver: str = typer.Argument(_drivers.Driver.CHROME.value),
     ver: str = None,
@@ -24,9 +24,16 @@ def _list_vers(driver: str):
 
 
 def main():
-    app = typer.Typer(pretty_exceptions_enable=False)
-    app.command()(_download)
-    app()
+    try:
+        app = typer.Typer(pretty_exceptions_enable=False)
+        app.command()(_main)
+        app()
+        return
+    except SystemExit:
+        ...
+    except:
+        bug_report_link = 'https://github.com/m9810223/selenium_setup/issues'
+        print(f'\n\n  >>> {bug_report_link = }\n')
 
 
 if __name__ == '__main__':
